pub struct Conditional {
pub condition: Box<Node>,
pub body: Vec<Node>,
pub else_body: Vec<Node>,
pub span: SourceSpan,
pub if_locals: Option<Vec<Variable>>,
pub else_locals: Option<Vec<Variable>>,
}Fields
condition: Box<Node>The condition
body: Vec<Node>The body
else_body: Vec<Node>If there is an else condition, this is its body
span: SourceSpanThe span
if_locals: Option<Vec<Variable>>A cache of local variables defined in the conditional if block.
else_locals: Option<Vec<Variable>>A cache of local variables defined in the conditional else block.
Implementations
Sourceimpl Conditional
impl Conditional
pub fn get_if_locals(&mut self) -> Vec<Variable>
pub fn get_else_locals(&mut self) -> Vec<Variable>
pub fn get_if_subroutines(&self) -> HashMap<String, Subroutine>
pub fn get_else_subroutines(&self) -> HashMap<String, Subroutine>
Sourceimpl Conditional
impl Conditional
pub fn cache(&mut self, cx: &CheckerContext) -> Result<()>